==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UDPRouteFluent<A extends UDPRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public UDPRouteFluent.MetadataNested<A> withNewMetadata();
  public UDPRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public UDPRouteFluent.MetadataNested<A> editMetadata();
  public UDPRouteFluent.MetadataNested<A> editOrNewMetadata();
  public UDPRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteSpec getSpec();
  public UDPRouteSpec buildSpec();
  public A withSpec(UDPRouteSpec spec);
  public Boolean hasSpec();
  public UDPRouteFluent.SpecNested<A> withNewSpec();
  public UDPRouteFluent.SpecNested<A> withNewSpecLike(UDPRouteSpec item);
  public UDPRouteFluent.SpecNested<A> editSpec();
  public UDPRouteFluent.SpecNested<A> editOrNewSpec();
  public UDPRouteFluent.SpecNested<A> editOrNewSpecLike(UDPRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteStatus getStatus();
  public UDPRouteStatus buildStatus();
  public A withStatus(UDPRouteStatus status);
  public Boolean hasStatus();
  public UDPRouteFluent.StatusNested<A> withNewStatus();
  public UDPRouteFluent.StatusNested<A> withNewStatusLike(UDPRouteStatus item);
  public UDPRouteFluent.StatusNested<A> editStatus();
  public UDPRouteFluent.StatusNested<A> editOrNewStatus();
  public UDPRouteFluent.StatusNested<A> editOrNewStatusLike(UDPRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<UDPRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,UDPRouteSpecFluent<UDPRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,UDPRouteStatusFluent<UDPRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/UDPRouteFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UDPRouteFluent<A extends UDPRouteFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public UDPRouteFluent.MetadataNested<A> withNewMetadata();
  public UDPRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public UDPRouteFluent.MetadataNested<A> editMetadata();
  public UDPRouteFluent.MetadataNested<A> editOrNewMetadata();
  public UDPRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteSpec getSpec();
  public UDPRouteSpec buildSpec();
  public A withSpec(UDPRouteSpec spec);
  public Boolean hasSpec();
  public UDPRouteFluent.SpecNested<A> withNewSpec();
  public UDPRouteFluent.SpecNested<A> withNewSpecLike(UDPRouteSpec item);
  public UDPRouteFluent.SpecNested<A> editSpec();
  public UDPRouteFluent.SpecNested<A> editOrNewSpec();
  public UDPRouteFluent.SpecNested<A> editOrNewSpecLike(UDPRouteSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public UDPRouteStatus getStatus();
  public UDPRouteStatus buildStatus();
  public A withStatus(UDPRouteStatus status);
  public Boolean hasStatus();
  public UDPRouteFluent.StatusNested<A> withNewStatus();
  public UDPRouteFluent.StatusNested<A> withNewStatusLike(UDPRouteStatus item);
  public UDPRouteFluent.StatusNested<A> editStatus();
  public UDPRouteFluent.StatusNested<A> editOrNewStatus();
  public UDPRouteFluent.StatusNested<A> editOrNewStatusLike(UDPRouteStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<UDPRouteFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,UDPRouteSpecFluent<UDPRouteFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,UDPRouteStatusFluent<UDPRouteFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
